@@ -1,3 +1,5 @@
+context("Calculation of an intersection")
+library(dst)
 test_that("inters_1", {
   # test fn with vectors
   mx <-c(1,1,0)
@@ -22,4 +24,11 @@ test_that("inters_3", {
   expect_equal(dim(result),c(3,3,2))
   expect_equivalent(result[,,1], matrix(c(0,0,0,0,0,1,0,0,1), ncol = 3, byrow = TRUE))
   expect_equivalent(result[,,2], matrix(c(0,1,0,0,1,1,1,1,1), ncol = 3, byrow = TRUE))
+})
+  test_that("inters_error", {
+    mx<-matrix(c(0,1,0,0,1,1,1,1,1),nrow=3, byrow = TRUE, dimnames = list(NULL, c("a", "b", "c")))
+    rownames(mx) <- nameRows(mx)
+    my<-matrix(c(0,0,1,1,1,1,1,1),nrow=2, byrow = TRUE, dimnames = list(NULL, c("a", "b", "c","d")))
+    rownames(my) <- nameRows(my)
+    expect_error(inters(mx,my), "Error in input arguments: check your input data.")
 })
\ No newline at end of file
